==> haskell-memotrie-0.6.11-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-memotrie.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 MemoTrie
version:              0.6.11
visibility:           public
id:                   MemoTrie-0.6.11-683GLED39WN6p5yoyZxvVY
key:                  MemoTrie-0.6.11-683GLED39WN6p5yoyZxvVY
license:              BSD-3-Clause
copyright:            (c) 2008-2019 by Conal Elliott
maintainer:           conal@conal.net
author:               Conal Elliott 
stability:            experimental
homepage:             https://github.com/conal/MemoTrie
synopsis:             Trie-based memo functions
description:
    MemoTrie provides a basis for memoized functions over some domains,
    using tries.  It'\''s based on ideas from Ralf Hinze and code from
    Spencer Janssen. Generic support thanks to Sam Boosalis.

    Project wiki page: <http://haskell.org/haskellwiki/MemoTrie>

    &#199; 2008-2019 by Conal Elliott; BSD3 license.

category:             Data
abi:                  c49d047f56889a9cd50ac22d8ce1514b
exposed:              True
exposed-modules:      Data.MemoTrie
import-dirs:          /usr/lib/ghc-9.4.8/site-local/MemoTrie-0.6.11
library-dirs:         /usr/lib/ghc-9.4.8/site-local/MemoTrie-0.6.11
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/MemoTrie-0.6.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-memotrie
hs-libraries:         HSMemoTrie-0.6.11-683GLED39WN6p5yoyZxvVY
depends:
    base-4.17.2.1 newtype-generics-0.6.2-3ve67hNis6E4GkLV4Hu6Gg

haddock-interfaces:   /usr/share/doc/haskell-memotrie/html/MemoTrie.haddock
haddock-html:         /usr/share/doc/haskell-memotrie/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-memotrie-0.6.11-19-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-memotrie.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 MemoTrie
version:              0.6.11
visibility:           public
id:                   MemoTrie-0.6.11-7tFkM86EhSwFBFe3VBDGh2
key:                  MemoTrie-0.6.11-7tFkM86EhSwFBFe3VBDGh2
license:              BSD-3-Clause
copyright:            (c) 2008-2019 by Conal Elliott
maintainer:           conal@conal.net
author:               Conal Elliott 
stability:            experimental
homepage:             https://github.com/conal/MemoTrie
synopsis:             Trie-based memo functions
description:
    MemoTrie provides a basis for memoized functions over some domains,
    using tries.  It'\''s based on ideas from Ralf Hinze and code from
    Spencer Janssen. Generic support thanks to Sam Boosalis.

    Project wiki page: <http://haskell.org/haskellwiki/MemoTrie>

    &#199; 2008-2019 by Conal Elliott; BSD3 license.

category:             Data
abi:                  4b0a9e505ea3b492ff9dd85396bad1a3
exposed:              True
exposed-modules:      Data.MemoTrie
import-dirs:          /usr/lib/ghc-9.4.8/site-local/MemoTrie-0.6.11
library-dirs:         /usr/lib/ghc-9.4.8/site-local/MemoTrie-0.6.11
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/MemoTrie-0.6.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-memotrie
hs-libraries:         HSMemoTrie-0.6.11-7tFkM86EhSwFBFe3VBDGh2
depends:
    base-4.17.2.1 newtype-generics-0.6.2-4sYNSYhUWmmwIso4LuCN1

haddock-interfaces:   /usr/share/doc/haskell-memotrie/html/MemoTrie.haddock
haddock-html:         /usr/share/doc/haskell-memotrie/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
